#ifndef NT2_INCLUDE_FUNCTIONS_CUMPROD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CUMPROD_HPP_INCLUDED

#include <nt2/swar/include/functions/cumprod.hpp>

#endif
